(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue'], factory) :
  (global = global || self, factory(global.VueLazyYoutubeVideo = {}, global.Vue));
}(this, (function (exports, Vue) { 'use strict';

  Vue = Vue && Vue.hasOwnProperty('default') ? Vue['default'] : Vue;

  var script = Vue.extend({
      name: 'VueLazyYoutubeVideo',
      props: {
          url: {
              type: String,
              required: true,
              validator: value => {
                  if (typeof value === 'string') {
                      return value.startsWith('https://www.youtube.com/watch?v=');
                  }
                  else {
                      return false;
                  }
              },
          },
          query: {
              type: String,
              default: '?autoplay=1',
          },
          alt: {
              type: String,
              default: 'Video thumbnail',
          },
          buttonLabel: {
              type: String,
              default: 'Play video',
          },
          aspectRatio: {
              type: String,
              default: '16:9',
              validator: value => {
                  const pattern = /^\d+:\d+$/;
                  return pattern.test(value);
              },
          },
          previewImageSize: {
              type: String,
              default: 'maxresdefault',
              validator: value => [
                  'default',
                  'mqdefault',
                  'sddefault',
                  'hqdefault',
                  'maxresdefault',
              ].indexOf(value) !== -1,
          },
          thumbnail: {
              type: Object,
              validator: val => 'jpg' in val && 'webp' in val
          },
          noCookie: {
              type: Boolean,
              default: false,
          },
          iframeAttributes: {
              type: Object
          }
      },
      data() {
          return {
              clicked: false,
          };
      },
      computed: {
          id() {
              const regExp = /^https:\/\/www\.youtube\.com\/watch\?v=(.+)$/;
              const executionResult = regExp.exec(this.url);
              if (executionResult !== null) {
                  return executionResult[1];
              }
              else {
                  this.warn(`Failed to extract video id from ${this.url}`);
                  return '';
              }
          },
          styleObj() {
              return {
                  paddingBottom: this.getPaddingBottom(),
              };
          },
      },
      methods: {
          generateURL() {
              return `https://www.youtube${this.noCookie ? '-nocookie' : ''}.com/embed/${this.id}${this.query}`;
          },
          clickHandler() {
              this.clicked = true;
              this.$nextTick(() => {
                  this.$emit('videoLoaded');
              });
          },
          getPaddingBottom() {
              let { aspectRatio } = this;
              // Vue does not provide correct typescript support
              // @ts-ignore
              const defaultAspectRatio = this.$options.props.aspectRatio.default;
              const warningMessage = `Invalid value ${aspectRatio} supplied to \`aspectRatio\` property, instead fallback value ${defaultAspectRatio} is used `;
              if (typeof aspectRatio === 'string') {
                  const [a, b] = aspectRatio.split(':');
                  if (Number.isFinite(Number(a)) && Number.isFinite(Number(b))) ;
                  else {
                      aspectRatio = defaultAspectRatio;
                      this.warn(warningMessage);
                  }
              }
              else {
                  aspectRatio = defaultAspectRatio;
                  this.warn(warningMessage);
              }
              const [a, b] = aspectRatio.split(':');
              return this.getPaddingBottomValue(Number(a), Number(b));
          },
          getPaddingBottomValue(a, b) {
              return `${(b / a) * 100}%`;
          },
          warn(message) {
              console.warn(`[vue-lazy-youtube-video]: ${message}`);
          }
      },
  });

  function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
      if (typeof shadowMode !== 'boolean') {
          createInjectorSSR = createInjector;
          createInjector = shadowMode;
          shadowMode = false;
      }
      // Vue.extend constructor export interop.
      const options = typeof script === 'function' ? script.options : script;
      // render functions
      if (template && template.render) {
          options.render = template.render;
          options.staticRenderFns = template.staticRenderFns;
          options._compiled = true;
          // functional template
          if (isFunctionalTemplate) {
              options.functional = true;
          }
      }
      // scopedId
      if (scopeId) {
          options._scopeId = scopeId;
      }
      let hook;
      if (moduleIdentifier) {
          // server build
          hook = function (context) {
              // 2.3 injection
              context =
                  context || // cached call
                      (this.$vnode && this.$vnode.ssrContext) || // stateful
                      (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
              // 2.2 with runInNewContext: true
              if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                  context = __VUE_SSR_CONTEXT__;
              }
              // inject component styles
              if (style) {
                  style.call(this, createInjectorSSR(context));
              }
              // register component module identifier for async chunk inference
              if (context && context._registeredComponents) {
                  context._registeredComponents.add(moduleIdentifier);
              }
          };
          // used by ssr in case component is cached and beforeCreate
          // never gets called
          options._ssrRegister = hook;
      }
      else if (style) {
          hook = shadowMode
              ? function (context) {
                  style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
              }
              : function (context) {
                  style.call(this, createInjector(context));
              };
      }
      if (hook) {
          if (options.functional) {
              // register for functional component in vue file
              const originalRender = options.render;
              options.render = function renderWithStyleInjection(h, context) {
                  hook.call(context);
                  return originalRender(h, context);
              };
          }
          else {
              // inject component registration as beforeCreate hook
              const existing = options.beforeCreate;
              options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
          }
      }
      return script;
  }

  const isOldIE = typeof navigator !== 'undefined' &&
      /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
  function createInjector(context) {
      return (id, style) => addStyle(id, style);
  }
  let HEAD;
  const styles = {};
  function addStyle(id, css) {
      const group = isOldIE ? css.media || 'default' : id;
      const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
      if (!style.ids.has(id)) {
          style.ids.add(id);
          let code = css.source;
          if (css.map) {
              // https://developer.chrome.com/devtools/docs/javascript-debugging
              // this makes source maps inside style tags work properly in Chrome
              code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
              // http://stackoverflow.com/a/26603875
              code +=
                  '\n/*# sourceMappingURL=data:application/json;base64,' +
                      btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                      ' */';
          }
          if (!style.element) {
              style.element = document.createElement('style');
              style.element.type = 'text/css';
              if (css.media)
                  style.element.setAttribute('media', css.media);
              if (HEAD === undefined) {
                  HEAD = document.head || document.getElementsByTagName('head')[0];
              }
              HEAD.appendChild(style.element);
          }
          if ('styleSheet' in style.element) {
              style.styles.push(code);
              style.element.styleSheet.cssText = style.styles
                  .filter(Boolean)
                  .join('\n');
          }
          else {
              const index = style.ids.size - 1;
              const textNode = document.createTextNode(code);
              const nodes = style.element.childNodes;
              if (nodes[index])
                  style.element.removeChild(nodes[index]);
              if (nodes.length)
                  style.element.insertBefore(textNode, nodes[index]);
              else
                  style.element.appendChild(textNode);
          }
      }
  }

  /* script */
  const __vue_script__ = script;

  /* template */
  var __vue_render__ = function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c(
      "div",
      { staticClass: "y-video", on: { click: _vm.clickHandler } },
      [
        _c(
          "div",
          { staticClass: "y-video__inner", style: _vm.styleObj },
          [
            _vm.clicked
              ? _c(
                  "iframe",
                  _vm._b(
                    {
                      staticClass: "y-video__media",
                      attrs: {
                        src: _vm.generateURL(),
                        allowfullscreen: "",
                        frameborder: "0",
                        allow:
                          "accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                      }
                    },
                    "iframe",
                    _vm.iframeAttributes,
                    false
                  )
                )
              : [
                  _c("picture", [
                    _c("source", {
                      attrs: {
                        srcset:
                          (_vm.thumbnail && _vm.thumbnail.webp) ||
                          "https://i.ytimg.com/vi_webp/" +
                            _vm.id +
                            "/" +
                            _vm.previewImageSize +
                            ".webp",
                        type: "image/webp"
                      }
                    }),
                    _vm._v(" "),
                    _c("img", {
                      staticClass: "y-video__media y-video__media--type--img",
                      attrs: {
                        src:
                          (_vm.thumbnail && _vm.thumbnail.jpg) ||
                          "https://i.ytimg.com/vi/" +
                            _vm.id +
                            "/" +
                            _vm.previewImageSize +
                            ".jpg",
                        alt: _vm.alt
                      }
                    })
                  ]),
                  _vm._v(" "),
                  _vm._t("button", [
                    _c(
                      "button",
                      {
                        staticClass: "y-video__button",
                        attrs: { type: "button", "aria-label": _vm.buttonLabel }
                      },
                      [
                        _vm._t("icon", [
                          _c(
                            "svg",
                            {
                              attrs: {
                                viewBox: "0 0 68 48",
                                version: "1.1",
                                width: "100%",
                                height: "100%"
                              }
                            },
                            [
                              _c("path", {
                                staticClass: "y-video__button-shape",
                                attrs: {
                                  d:
                                    "M66.5 7.7c-.8-2.9-2.5-5.4-5.4-6.2C55.8.1 34 0 34 0S12.2.1 6.9 1.6c-3 .7-4.6 3.2-5.4 6.1a89.6 89.6 0 0 0 0 32.5c.8 3 2.5 5.5 5.4 6.3C12.2 47.9 34 48 34 48s21.8-.1 27.1-1.6c3-.7 4.6-3.2 5.4-6.1C68 35 68 24 68 24s0-11-1.5-16.3z"
                                }
                              }),
                              _vm._v(" "),
                              _c("path", {
                                staticClass: "y-video__button-icon",
                                attrs: { d: "M45 24L27 14v20" }
                              })
                            ]
                          )
                        ])
                      ],
                      2
                    )
                  ])
                ]
          ],
          2
        )
      ]
    )
  };
  var __vue_staticRenderFns__ = [];
  __vue_render__._withStripped = true;

    /* style */
    const __vue_inject_styles__ = function (inject) {
      if (!inject) return
      inject("data-v-72da1595_0", { source: "\n:root {\n  --y-video-background-color: #000;\n  --y-video-button-width: 68px;\n  --y-video-button-height: 48px;\n  --y-video-button-padding: 0;\n  --y-video-button-border-width: 0;\n  --y-video-button-background-color: transparent;\n  --y-video-button-fill: #212121;\n  --y-video-button-fill-opacity: 0.8;\n  --y-video-button-active-fill: red;\n  --y-video-button-active-fill-opacity: 1;\n  --y-video-button-icon-fill: #fff;\n}\n.y-video {\n  background-color: var(--y-video-background-color, #000);\n  cursor: pointer;\n}\n.y-video__inner {\n  position: relative;\n}\n.y-video__embed,\n.y-video__media {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  border-width: 0;\n}\n.y-video__media--type--img {\n  object-fit: cover;\n}\n.y-video__button {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  padding: var(--y-video-button-padding, 0);\n  border-width: var(--y-video-button-border-width, 0);\n  background-color: var(--y-video-button-background-color, transparent);\n  width: var(--y-video-button-width, 68px);\n  height: var(--y-video-button-height, 48px);\n  cursor: pointer;\n}\n.y-video__button-shape {\n  fill: var(--y-video-button-fill, #212121);\n  fill-opacity: var(--y-video-button-fill-opacity, 0.8);\n}\n.y-video__button-icon {\n  fill: var(--y-video-button-icon-fill, #fff);\n}\n.y-video__button:focus {\n  outline: 0;\n}\n.y-video__button:focus .y-video__button-shape {\n  fill: var(--y-video-button-active-fill, red);\n  fill-opacity: var(--y-video-button-active-fill-opacity, 1);\n}\n.y-video:hover .y-video__button-shape {\n  fill: var(--y-video-button-active-fill, red);\n  fill-opacity: var(--y-video-button-active-fill-opacity, 1);\n}\n", map: undefined, media: undefined });

    };
    /* scoped */
    const __vue_scope_id__ = undefined;
    /* module identifier */
    const __vue_module_identifier__ = undefined;
    /* functional template */
    const __vue_is_functional_template__ = false;
    /* style inject SSR */
    
    /* style inject shadow dom */
    

    
    const __vue_component__ = normalizeComponent(
      { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
      __vue_inject_styles__,
      __vue_script__,
      __vue_scope_id__,
      __vue_is_functional_template__,
      __vue_module_identifier__,
      false,
      createInjector,
      undefined,
      undefined
    );

  const Plugin = {
      install(Vue) {
          Vue.component('LazyYoutubeVideo', __vue_component__);
      },
  };

  exports.Plugin = Plugin;
  exports.default = __vue_component__;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
